vtool_ibeis
===========

|Pypi| |Downloads| |Codecov|

Vision Tools - tools for computer vision. Part of the WildMe / IBEIS Project.


Repos relevant to the ibeis project:

* https://github.com/Erotemic/plottool_ibeis

* https://github.com/Erotemic/guitool_ibeis

* https://github.com/Erotemic/dtool_ibeis

* https://github.com/Erotemic/vtool_ibeis

* https://github.com/Erotemic/vtool_ibeis_ext

* https://github.com/Erotemic/pyflann_ibeis

* https://github.com/Erotemic/pyhesaff

* https://github.com/Erotemic/utool

* https://github.com/Erotemic/ibeis


.. |Codecov| image:: https://codecov.io/github/Erotemic/vtool_ibeis/badge.svg?branch=master&service=github
   :target: https://codecov.io/github/Erotemic/vtool_ibeis?branch=master
.. |Pypi| image:: https://img.shields.io/pypi/v/vtool_ibeis.svg
   :target: https://pypi.python.org/pypi/vtool_ibeis
.. |Downloads| image:: https://img.shields.io/pypi/dm/vtool_ibeis.svg
   :target: https://pypistats.org/packages/vtool_ibeis
.. |ReadTheDocs| image:: https://readthedocs.org/projects/vtool_ibeis/badge/?version=latest
    :target: http://vtool_ibeis.readthedocs.io/en/latest/
